@@ -40,9 +40,18 @@ colors = {
 
 plt.style.use('default')
 plt.rcParams.update({
-    'figure.facecolor': (1.0, 1.0, 1.0, 0.0),
-    'axes.facecolor': (1.0, 1.0, 1.0, 0.0),
     'image.cmap': 'viridis',
+    'savefig.transparent': True,
+    'text.color': '#666666',
+    'axes.labelcolor': '#666666',
+    'xtick.color': '#66666604',
+    'ytick.color': '#66666604',
+    'ytick.labelcolor': '#666666',
+    'xtick.labelcolor': '#666666',
+    'axes.edgecolor': '#66666600',
+    'grid.color': (0.4, 0.4, 0.4, 0.4),  # #66666602
+    'axes.facecolor': (1.0, 1.0, 1.0, 0.0),
+    'figure.facecolor': (1.0, 1.0, 1.0, 0.0),
 })
 # sns.set_palette(list(colors.values()))
 # sns.set_context('notebook', font_scale=0.8)
@@ -197,8 +206,6 @@ def plot_combined(
         val: xr.DataArray,
         key: str = None,
         num_chains: int = 10,
-        # title: str = None,
-        # outdir: str = None,
         subplots_kwargs: dict[str, Any] = None,
         plot_kwargs: dict[str, Any] = None,
 ) -> tuple:
@@ -216,21 +223,23 @@ def plot_combined(
     vmin = np.min(val)
     vmax = np.max(val)
     if vmin < 0 < vmax:
-        color = '#FF5252' if val.mean() > 0 else '#007DFF'
+        color = '#FF5252' if val.mean() > 0 else '#2979FF'
     elif 0 < vmin < vmax:
         color = '#3FB5AD'
     else:
         color = plot_kwargs.get('color', f'C{np.random.randint(5)}')
 
     (ax1, ax2) = subfigs[1].subplots(1, 2, sharey=True, gridspec_kw=gs_kw)
-    ax1.grid(alpha=0.2)
+    ax1.grid(alpha=0.4)
     ax2.grid(False)
     sns.kdeplot(y=val.values.flatten(), ax=ax2, color=color, shade=True)
     axes = (ax1, ax2)
     ax0 = subfigs[0].subplots(1, 1)
     val = val.dropna('chain')
-    _ = xplt.pcolormesh(val, 'draw', 'chain', ax=ax0,
-                        robust=True, add_colorbar=True)
+    # _ = xplt.pcolormesh(val, 'draw', 'chain', ax=ax0,
+    #                     robust=True, add_colorbar=True)
+    _ = xplt.imshow(val, 'draw', 'chain', ax=ax0,
+                    robust=True, add_colorbar=True)
     nchains = min((num_chains, len(val.coords['chain'])))
     label = f'{key}_avg'
     # label = r'$\langle$' + f'{key} ' + r'$\rangle$'
@@ -284,8 +293,8 @@ def plot_dataArray(
     if therm_frac > 0:
         drop = int(therm_frac * arr.shape[0])
         arr = arr[drop:]
-
         steps = steps[drop:]
+
     if len(arr.shape) == 2:
         fig, axes = plot_combined(val, key=key,
                                   num_chains=num_chains,
@@ -466,7 +475,7 @@ def plot_metric(
         gs_kw = {'width_ratios': [1.33, 0.33]}
         (ax, ax1) = subfigs[1].subplots(1, 2, sharey=True,
                                         gridspec_kw=gs_kw)
-        ax.grid(alpha=0.2)
+        ax.grid(alpha=0.4)
         ax1.grid(False)
         color = plot_kwargs.get('color', 'C0')
         label = plot_kwargs.pop('label', None)
@@ -620,8 +629,9 @@ def plot_dataset(
 def make_ridgeplots(
         dataset: xr.Dataset,
         num_chains: int = None,
-        out_dir: os.PathLike = None,
+        outdir: os.PathLike = None,
         drop_zeros: bool = False,
+        drop_nans: bool = True,
         cmap: str = 'viridis_r',
         # default_style: dict = None,
 ):
@@ -649,6 +659,9 @@ def make_ridgeplots(
                 if drop_zeros:
                     x = x[x != 0]
                 #  x = val[{'leapfrog': lf}].values.flatten()
+                if drop_nans:
+                    x = x[np.isfinite(x)]
+
                 lf_arr = np.array(len(x) * [f'{lf}'])
                 lf_data[key].extend(x)
                 lf_data['lf'].extend(lf_arr)
@@ -686,13 +699,18 @@ def make_ridgeplots(
             _ = g.set(yticks=[])
             _ = g.set(yticklabels=[])
             _ = g.despine(bottom=True, left=True)
-            if out_dir is not None:
-                # io.check_else_make_dir(out_dir)
-                # out_file = os.path.join(out_dir, f'{key}_ridgeplot.svg')
-                outfile = Path(out_dir).joinpath(f'{key}_ridgeplot.svg')
-                outfile.parent.mkdir(exist_ok=True, parents=True)
-                #  logger.log(f'Saving figure to: {out_file}.')
-                plt.savefig(outfile.as_posix(), dpi=400, bbox_inches='tight')
+            if outdir is not None:
+                outdir = Path(outdir)
+                pngdir = outdir.joinpath('pngs')
+                fsvg = Path(outdir).joinpath(f'{key}_ridgeplot.svg')
+                fpng = Path(pngdir).joinpath(f'{key}_ridgeplot.png')
+
+                outdir.mkdir(exist_ok=True, parents=True)
+                pngdir.mkdir(exist_ok=True, parents=True)
+
+                log.info(f'Saving figure to: {fsvg.as_posix()}')
+                plt.savefig(fsvg.as_posix(), dpi=500, bbox_inches='tight')
+                plt.savefig(fpng.as_posix(), dpi=500, bbox_inches='tight')
 
         # plt.close('all')
 
